import { Breakpoint, ParameterizedDeclaration, RecognizedDeclaration } from "./types";
export interface DocumentationGenerator {
    /**
     * Choose the order of definitions in the `exposing` clause for the utilities module.
     * `null` indicates that `exposing (..)` should be generated.
     */
    utilitiesExposing: (definedNames: string[]) => string[] | null;
    /**
     * Return a doc string for the utilities module, given all definitions that will be generated.
     * The resulting string has to contain the `{-|` and `-}` parts.
     * `null` indicates no documentation should be generated.
     */
    utilitiesModuleDocs: (definedNames: string[]) => string | null;
    /**
     * Called for documentation generation for the globalStyles definition.
     * The output string can be empty or otherwise has to contain the `{-|` and `-}` parts.
     */
    utilitiesGlobalStyles: () => string;
    /**
     * Called for every generated tailwind utility definition.
     * The output string can be empty or otherwise has to contain the `{-|` and `-}` parts.
     */
    utilitiesDefinition: (name: string, declaration: RecognizedDeclaration) => string;
    /**
     * Called for groups of abstracted tailwind utility definitions.
     * The output string can be empty or otherwise has to contian the `{-|` and `-}` parts.
     */
    utilitiesParameterizedDefinition: (name: string, declaration: ParameterizedDeclaration) => string;
    /**
     * Choose the order of definitions in the `exposing` clause for the breakpoints module.
     * `null` indicates that `exposing (..)` should be generated.
     */
    breakpointsExposing: (definedNames: string[]) => string[] | null;
    /**
     * Return a doc string for the breakpoints module, given all definitions that will be generated.
     * The resulting string has to contain the `{-|` and `-}` parts.
     * `null` indicates no documentation should be generated.
     */
    breakpointsModuleDocs: (definedNames: string[]) => string | null;
    /**
     * Called for every generated tailwind breakpoints definition.
     * The output string can be empty or otherwise has to contain the `{-|` and `-}` parts.
     */
    breakpointsDefinition: (breakpoint: Breakpoint) => string;
    /**
     * Called for every tailwind theme color definition.
     */
    themeColorDefinition: (name: string, value: string) => string;
    /**
     * Called for every tailwind theme opacity definition.
     */
    themeOpacityDefinition: (name: string, value: string) => string;
}
export declare const noDocumentationGenerator: DocumentationGenerator;
export declare const defaultDocumentationGenerator: DocumentationGenerator;
export declare const themeModuleDocumentation: (definedColors: string[], definedOpacities: string[]) => string;
